entity = {}
entity.table = {}
entity.stat = {
  maxspeed = 200,
  acceleration = 750,
  scale = 0.7,
}

function entity.new(name, type, color)
  local table = {
    name = name or "new entity",
    type = type or "static",
    color = color or {255,255,255},
    health = 100,
    x = 0,
    y = 0,
    xTile = 0,
    yTile = 0,
    spawnX = 0,
    spawnY = 0,
    sx = 0,
    sy = 0,
    maxspeed = entity.stat.maxspeed,
    drawmode = "fill",
    scaleX = entity.stat.scale,
    scaleY = entity.stat.scale,
    ang = 0,
  }

  entity.table[#entity.table+1] = table
  return table

end

function entity.spawn(ent)
  if ent and type(ent) == "table" then
    ent.health = 100
    if ent.spawnX == 0 and ent.spawnY == 0 then
      local index = math.random(#map.spawns)
      ent.x = map.convertCordTile(map.spawns[index][1])
      ent.y = map.convertCordTile(map.spawns[index][2])
    else
      ent.x = map.convertCordTile(ent.spawnX)
      ent.y = map.convertCordTile(ent.spawnY)
    end
  end
end

function entity.find(name)
  for k,v in pairs(entity.table) do
    if v.name == name then return v end
  end
end

function entity.update(dt)
  for k,v in pairs(entity.table) do
    if v.health > 0 or v.type == "static" then
      v.x = v.x + v.sx * dt
      v.y = v.y + v.sy * dt
      if v.sx > v.maxspeed then v.sx = v.maxspeed end
      if v.sy > v.maxspeed then v.sy = v.maxspeed end
      if v.sx < -v.maxspeed then v.sx = -v.maxspeed end
      if v.sy < -v.maxspeed then v.sy = -v.maxspeed end
    end
  end

  local ply = entity.find("player")

  if love.keyboard.isDown("w") then
    ply.sy = ply.sy - entity.stat.acceleration * dt
  elseif love.keyboard.isDown("s") then
    ply.sy = ply.sy + entity.stat.acceleration*dt
  else
    if ply.sy > 0 then ply.sy = ply.sy - entity.stat.acceleration*dt end
    if ply.sy < 0 then ply.sy = ply.sy + entity.stat.acceleration*dt end 
    if ply.sy < 10 and ply.sy > -10 then ply.sy = 0 end
  end

  if love.keyboard.isDown("a") then
    ply.sx = ply.sx - entity.stat.acceleration * dt
  elseif love.keyboard.isDown("d") then
    ply.sx = ply.sx + entity.stat.acceleration * dt
  else
    if ply.sx > 0 then ply.sx = ply.sx - entity.stat.acceleration*dt end
    if ply.sx < 0 then ply.sx = ply.sx + entity.stat.acceleration*dt end 
    if ply.sx < 10 and ply.sx > -10 then ply.sx = 0 end
  end
end

function entity.draw()
  for k,v in pairs(entity.table) do
    if v.health > 0 or v.type == "static" then
      v.tileX = v.x / (game.TILESIZE*game.TILESCALE)
      v.tileX = math.floor(v.tileX)
      v.tileY = v.y / (game.TILESIZE*game.TILESCALE)
      v.tileY = math.floor(v.tileY)
      love.graphics.setColor(v.color)
      love.graphics.rectangle(v.drawmode, v.x, v.y, game.TILESIZE*game.TILESCALE*v.scaleX, game.TILESIZE*game.TILESCALE*v.scaleY, v.ang)
      if game.DEBUG then
        love.graphics.setColor(255,255,255)
        love.graphics.print(v.name,v.x,v.y)
        love.graphics.print(v.health,v.x,v.y+15)
        love.graphics.print(v.tileX..", "..v.tileY, v.x, v.y+30)
      end
    end
  end
end

function entity.key(key)

end
